@@ -40,15 +40,17 @@
 #'
 #' @export
 bed_projection <- function(x, y, genome, by_chrom = FALSE) {
-
   if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
   if (!is.tbl_interval(y)) y <- as.tbl_interval(y)
   if (!is.tbl_genome(genome)) genome <- as.tbl_genome(genome)
 
-  #find midpoints
-  x <- mutate(x, .midpoint = round( (end + start) / 2),
-              start = .midpoint,
-              end = .midpoint + 1)
+  # find midpoints
+  x <- mutate(
+    x,
+    .midpoint = round((end + start) / 2),
+    start = .midpoint,
+    end = .midpoint + 1
+  )
   x <- select(x, -.midpoint)
 
   # flatten y intervals
@@ -61,14 +63,17 @@ bed_projection <- function(x, y, genome, by_chrom = FALSE) {
   obs_counts <- group_by(obs_counts, chrom)
   obs_counts <- summarize(obs_counts, .obs_counts = n())
 
-  #total x intervals tested
+  # total x intervals tested
   total_counts <- group_by(x, chrom)
   total_counts <- summarize(total_counts, .total_trials = n())
   obs_counts <- full_join(obs_counts, total_counts, by = "chrom")
-  obs_counts <- mutate(obs_counts,
-                       .obs_counts = if_else(is.na(.obs_counts),
-                                             as.integer(0),
-                                             .obs_counts))
+  obs_counts <- mutate(
+    obs_counts,
+    .obs_counts = if_else(is.na(.obs_counts),
+      as.integer(0),
+      .obs_counts
+    )
+  )
 
   # calculate probabilty of overlap by chance
   y <- mutate(y, .length = end - start)
@@ -83,36 +88,49 @@ bed_projection <- function(x, y, genome, by_chrom = FALSE) {
   res <- inner_join(obs_counts, null_dist, by = "chrom")
 
   # binomial test and obs/exp
-  if (by_chrom){
+  if (by_chrom) {
     res <- group_by(res, chrom)
-    res <- summarize(res,
-                     p.value = stats::pbinom(q = .obs_counts,
-                                      size = .total_trials,
-                                      prob = .exp_prob),
-                     obs_exp_ratio = (.obs_counts / .total_trials) / .exp_prob
-                     )
+    res <- summarize(
+      res,
+      p.value = stats::pbinom(
+        q = .obs_counts,
+        size = .total_trials,
+        prob = .exp_prob
+      ),
+      obs_exp_ratio = (.obs_counts / .total_trials) / .exp_prob
+    )
   } else {
     res <- ungroup(res)
-    res <- summarize(res,
-                     .obs_counts = sum(.obs_counts),
-                     .total_trials = sum(.total_trials),
-                     .exp_prob = sum(.reference_coverage) /
-                       sum(as.numeric(size)))
+    res <- summarize(
+      res,
+      .obs_counts = sum(.obs_counts),
+      .total_trials = sum(.total_trials),
+      .exp_prob = sum(.reference_coverage) /
+        sum(as.numeric(size))
+    )
 
-    res <- summarize(res,
-                     chrom = "whole_genome",
-                     p.value = stats::pbinom(q = .obs_counts,
-                                      size = .total_trials,
-                                      prob = .exp_prob),
-                     obs_exp_ratio = (.obs_counts / .total_trials) / .exp_prob)
+    res <- summarize(
+      res,
+      chrom = "whole_genome",
+      p.value = stats::pbinom(
+        q = .obs_counts,
+        size = .total_trials,
+        prob = .exp_prob
+      ),
+      obs_exp_ratio = (.obs_counts / .total_trials) / .exp_prob
+    )
   }
 
-  res <- mutate(res,
-                lower_tail = if_else(p.value < .5,
-                                     "TRUE",
-                                     "FALSE"),
-                p.value = if_else(p.value < .5,
-                                  p.value,
-                                  1 - p.value))
+  res <- mutate(
+    res,
+    lower_tail = if_else(p.value < .5,
+      "TRUE",
+      "FALSE"
+    ),
+    p.value = if_else(p.value < .5,
+      p.value,
+      1 - p.value
+    )
+  )
   res
 }
