@@ -34,11 +34,11 @@
 #' @export
 bed_random <- function(genome, length = 1000, n = 1e6,
                        sort_by = c("chrom", "start"), seed = 0) {
-
   if (!is.tbl_genome(genome)) genome <- as.tbl_genome(genome)
 
-  if (!all(genome$size > length))
+  if (!all(genome$size > length)) {
     stop("`length` must be greater than all chrom sizes", call. = FALSE)
+  }
 
   out <- random_impl(genome, length, n, seed)
 
@@ -47,6 +47,6 @@ bed_random <- function(genome, length = 1000, n = 1e6,
     out <- arrange(out, !!! sort_syms)
   }
 
-  out <- tibble::as_tibble(out)
+  out <- as.tbl_interval(out)
   out
 }
